package org.systemsbiology.chem;

import java.util.Date;

import org.systemsbiology.math.AccuracyException;
import org.systemsbiology.math.DoubleVector;
import org.systemsbiology.math.MutableInteger;
import org.systemsbiology.util.DataNotFoundException;
import org.systemsbiology.util.InvalidInputException;

import cern.jet.random.Normal;
import cern.jet.random.engine.MersenneTwister;
import edu.cornell.lassp.houle.RngPack.RandomElement;
import edu.cornell.lassp.houle.RngPack.Ranmar;


public class SimulatorStochasticSDEEulerMaruyama extends SimulatorStochasticBase implements ISimulator{

	public static final String CLASS_ALIAS = "euler-maruyama"; 
	
	@Override
	protected void modifyDefaultSimulatorParameters(
			SimulatorParameters pSimulatorParameters) {
		// nothig to do for now
		
	}

	@Override
	protected double iterate(MutableInteger pLastReactionIndex)
			throws DataNotFoundException, IllegalStateException,
			AccuracyException {
		
		int numReactions = mReactions.length;
		int numSymbols = mDynamicSymbolValues.length;
		double reactionRate = 0.0;
		
		double[] derivative = new double[numSymbols];
		double drift;
		double diffusion;
		double[] k = new double[numSymbols];
		
		//double[] scale = new double[numSymbols];
		
		RandomElement rngEngine=new MersenneTwister(new Date());
		Normal normalGnr = new Normal(0, 1, rngEngine);
		
		computeReactionProbabilities();
		
		
		DoubleVector.zeroElements(derivative);
		
		Object []dynamicSymbolAdjustmentVectors = mDynamicSymbolAdjustmentVectors;
		
		//should check for execution time and report in debug mode
		for(int i = 0; i < numReactions; i++) {
			reactionRate = mReactionProbabilities[i];
			drift = reactionRate * pStepSize;
			diffusion = Math.sqrt(Math.abs(drift)) * normalGnr.nextDouble();
			diffusion = drift + diffusion;
			double []symbolAdjustmentVector =(double[])dynamicSymbolAdjustmentVectors[i];
			
			DoubleVector.scalarMultiply(symbolAdjustmentVector, diffusion, k);
			DoubleVector.add(k, derivative, derivative);
		}
		
//		double sumScale = 0;
//		for(int i = 0; i < numSymbols; i++) {
//			
//			scale[i] = Math.abs(mDynamicSymbolValues[i]) + Math.abs(derivative[i]);
//			sumScale += scale[i];
//		}
//		if(sumScale == 0)
//			throw new AccuracyException("unable to determine any scale at time: " +	mSymbolEvaluator.getTime());
		
		DoubleVector.add(mDynamicSymbolValues,derivative,mDynamicSymbolValues);
		
		mSymbolEvaluator.setTime(mSymbolEvaluator.getTime() + pStepSize);
		return(mSymbolEvaluator.getTime());
		
	}

	@Override
	protected void prepareForStochasticSimulation(double pStartTime,
			SimulatorParameters pSimulatorParameters)
			throws DataNotFoundException, IllegalArgumentException {
		
		//nothing to do for now
		
	}
	


	@Override
	public String getAlias() {
		return(CLASS_ALIAS);
	}
	
	 
	@Override
	public void initialize(Model pModel) throws DataNotFoundException,
			InvalidInputException {
		    initializeSimulator(pModel);
	        initializeSimulatorStochastic(pModel);
	        initializeDynamicSymbolAdjustmentVectors();
	        setInitialized(true);
	}

}
